# FastVid
FastVid 是一个用于视频处理的图形用户界面工具，支持视频加速、GIF 转换和压缩等功能，后端依赖FFmpeg.

## 安装
通过 pip 安装 FastVid：

```bash
pip install fastvid
```

# GUI
<img src="/home/mellon/mellon/repo/fastvid/doc/gui.png" alt="GUI界面" width="1800" height="400">

# 功能项
- [x] 加速转换视频
- [x] 转换为GIF
- [x] 压缩视频
- [x] 裁剪视频
- [ ] 转换为MP4格式
- [ ] 截图
- [ ] 录制视频